BioSimulators utils documentation — BioSimulators utils 0.1.154 documentation

# BioSimulators utils documentation

Command-line application and high-level utilities for reading, writing, validating, and executing COMBINE/OMEX format files that contain descriptions of simulations in Simulation Experiment Description Markup Language (SED-ML) format with models in formats such as the BioNetGen Language (BNGL) and the Systems Biology Markup Language (SBML).

## Contents

- Installation instructions
  - Requirements
  - Optional requirements
  - Installing the latest release from PyPI
  - Installing the latest revision from GitHub
  - Installing the optional features
  - Dockerfile and Docker image
- Tutorials
- API documentation
  - Subpackages
  - Submodules
  - biosimulators_utils.config module
  - biosimulators_utils.data_model module
  - biosimulators_utils.exceptions module
  - biosimulators_utils.image module
  - biosimulators_utils.warnings module
- About BioSimulators utils
  - License
  - Development team
  - Contributing to BioSimulators utils
  - Acknowledgements
  - Questions and comments
- Index